//Copyright 2011 Desire2Learn Incorporated
//
//Licensed under the Apache License, Version 2.0 (the "License");
//you may not use this file except in compliance with the License.
//You may obtain a copy of the License at
//
//http://www.apache.org/licenses/LICENSE-2.0
//
//Unless required by applicable law or agreed to in writing, software
//distributed under the License is distributed on an "AS IS" BASIS,
//WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//See the License for the specific language governing permissions and
//limitations under the License.


#import <Foundation/Foundation.h>

/**
 * The screenshot assistant is provided for use by modules that want
 * to manually control how automatic screenshots of the module are
 * generated.  The assistant object is provided to the module 
 * through the takeScreenshots: method.
 */


@protocol D2LModuleScreenshotAssistant <NSObject>

/**
 * Call this method to generate a screenshot of your module's current state.
 */
- (void)takeScreenshot;

/**
 * Call this method to generate a screenshot of your module after a given time
 * period, then call a notification method.
 *
 * @param delay - The time to wait after calling the method to take a screenshot.
 * @param target - The object to notify after the screenshot is taken.
 * @param action - The method to call on the object after the screenshot is taken.
 */
- (void)takeScreenshotAfterDelay:(NSTimeInterval)delay target:(id)target action:(SEL)action;

/**
 * Call this method once your module has finished taking screenshots.
 */
- (void)finish;

@end
